@@ -2,11 +2,14 @@
 #'
 #' @description
 #' Brier score for binary classification problems defined as \deqn{
-#'    \frac{1}{n} \sum_{i=1}^n (I_i - p_i)^2.
+#'    \frac{1}{n} \sum_{i=1}^n w_i (I_i - p_i)^2.
 #' }{
-#'    1/n * sum(((t == positive) - p)^2).
+#'    weighted.mean(((t == positive) - p)^2, w).
 #' }
+#' \if{latex}{
+#' \eqn{w_i} are the sample weights,
 #' \eqn{I_{i}}{I_i} is 1 if observation \eqn{i} belongs to the positive class, and 0 otherwise.
+#' }
 #'
 #' Note that this (more common) definition of the Brier score is equivalent to the
 #' original definition of the multi-class Brier score (see [mbrier()]) divided by 2.
@@ -22,9 +25,9 @@
 #' @inheritParams binary_params
 #' @template binary_example
 #' @export
-bbrier = function(truth, prob, positive, ...) {
+bbrier = function(truth, prob, positive, sample_weights = NULL, ...) {
   assert_binary(truth, prob = prob, positive = positive)
-  mean(se(truth == positive, prob))
+  wmean(se(truth == positive, prob), sample_weights)
 }
 
 #' @include measures.R
