@@ -9,7 +9,7 @@
 #' @templateVar mid prauc
 #' @template binary_template
 #'
-#' @note
+#' @details
 #' This measure is undefined if the true values are either all positive or
 #' all negative.
 #'
@@ -30,10 +30,11 @@ prauc = function(truth, prob, positive, na_value = NaN, ...) {
   n_pos = length(i)
   n_neg = length(truth) - n_pos
 
-  if (n_pos == 0L || n_neg == 0L)
+  if (n_pos == 0L || n_neg == 0L) {
     return(na_value)
+  }
 
-  truth <- ifelse(truth == positive, 1, 0)
+  truth = ifelse(truth == positive, 1, 0)
   PRROC::pr.curve(
     scores.class0 = prob,
     weights.class0 = truth
