@@ -2,9 +2,9 @@
 #'
 #' @description
 #' Classification measure defined as \deqn{
-#'   \frac{1}{n} \sum_{i=1}^n \left( t_i = r_i \right).
+#'   \frac{1}{n} \sum_{i=1}^n w_i \left( t_i = r_i \right).
 #' }{
-#'   mean(t == r).
+#'   weighted.mean(t == r, w).
 #' }
 #'
 #' @templateVar mid acc
@@ -13,9 +13,9 @@
 #' @inheritParams classif_params
 #' @template classif_example
 #' @export
-acc = function(truth, response, ...) {
+acc = function(truth, response, sample_weights = NULL, ...) {
   assert_classif(truth, response = response)
-  mean(truth == response)
+  wmean(truth == response, sample_weights)
 }
 
 acc_cm = function(m, na_value = NaN) {
