@@ -2,9 +2,9 @@
 #'
 #' @description
 #' Regression measure defined as \deqn{
-#'   \frac{1}{n} \sum_{i=1}^n \left( t_i - r_i \right)^2.
+#'   \frac{1}{n} w_i \sum_{i=1}^n \left( t_i - r_i \right)^2.
 #' }{
-#'   mean((t - r)^2).
+#'   weighted.mean((t - r)^2, w).
 #' }
 #'
 #' @templateVar mid mse
@@ -13,9 +13,9 @@
 #' @inheritParams regr_params
 #' @template regr_example
 #' @export
-mse = function(truth, response, ...) {
+mse = function(truth, response, sample_weights = NULL, ...) {
   assert_regr(truth, response = response)
-  mean(se(truth, response))
+  wmean(se(truth, response), sample_weights)
 }
 
 #' @include measures.R
