@@ -2,9 +2,9 @@
 #'
 #' @description
 #' Regression measure defined as \deqn{
-#'   \frac{1}{n} \sum_{i=1}^n \frac{\left( t_i - r_i \right)}{\left| t_i \right|}.
+#'   \frac{1}{n} \sum_{i=1}^n w_i \frac{\left( t_i - r_i \right)}{\left| t_i \right|}.
 #' }{
-#'   mean((t - r) / abs(t)).
+#'   weighted.mean((t - r) / abs(t), w).
 #' }
 #' Good predictions score close to 0.
 #'
@@ -14,11 +14,12 @@
 #' @inheritParams regr_params
 #' @template regr_example
 #' @export
-pbias = function(truth, response, na_value = NaN, ...) {
+pbias = function(truth, response, sample_weights = NULL, na_value = NaN, ...) {
   assert_regr(truth, response = response, na_value = na_value)
-  if (any(abs(truth) < TOL))
+  if (any(abs(truth) < TOL)) {
     return(na_value)
-  mean((truth - response) / abs(truth))
+  }
+  wmean((truth - response) / abs(truth), sample_weights)
 }
 
 #' @include measures.R
