@@ -2,9 +2,9 @@
 #'
 #' @description
 #' Regression measure defined as \deqn{
-#'   \sqrt{\frac{1}{n} \sum_{i=1}^n \left( t_i - r_i \right)^2}.
+#'   \sqrt{\frac{1}{n} \sum_{i=1}^n w_i \left( t_i - r_i \right)^2}.
 #' }{
-#'   sqrt(mean((t - r)^2)).
+#'   sqrt(weighted.mean((t - r)^2, w)).
 #' }
 #'
 #' @templateVar mid rmse
@@ -13,9 +13,9 @@
 #' @inheritParams regr_params
 #' @template regr_example
 #' @export
-rmse = function(truth, response, ...) {
+rmse = function(truth, response, sample_weights = NULL, ...) {
   assert_regr(truth, response = response)
-  sqrt(mean(se(truth, response)))
+  sqrt(wmean(se(truth, response), sample_weights))
 }
 
 #' @include measures.R
