@@ -14,7 +14,7 @@
 #' @templateVar mid rsq
 #' @template regr_template
 #'
-#' @note
+#' @details
 #' This measure is undefined for constant \eqn{t}.
 #'
 #' @inheritParams regr_params
@@ -23,8 +23,9 @@
 rsq = function(truth, response, na_value = NaN, ...) {
   assert_regr(truth, response = response, na_value = na_value)
   v = var(truth)
-  if (v < TOL)
+  if (v < TOL) {
     return(na_value)
+  }
   1 - sum(se(truth, response)) / (v * (length(truth) - 1L))
 }
 
